@@ -2,7 +2,7 @@
 * This file is part of Converseen, an open-source batch image converter
 * and resizer.
 *
-* (C) Francesco Mondello 2009 - 2022
+* (C) Francesco Mondello 2009 - 2023
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -56,6 +56,11 @@ int main(int argc, char ** argv)
         if (QString::fromStdString(argv[1]) == "--list") {
             win.importListFromArgv(QString::fromStdString(argv[2]));
         }
+
+        // Prints the readable/writable supported formats by IM
+        if (QString::fromStdString(argv[1]) == "--supported-formats") {
+            win.printSupportedFormats();
+        }
     }
 
     win.show();
